@@ -1,3 +1,6 @@
+import time
+from datetime import datetime
+
 from collections import defaultdict
 import pandas as pd
 
@@ -33,3 +36,13 @@ def get_avg_dist_per_dest(od_matrix_file_path, dist_matrix_file_path, adm_code_c
     od_matrix['temp'] = od_matrix['dist'] * od_matrix[count_col_name] / groups[count_col_name].transform('sum')
 
     return dict(groups['temp'].sum())
+
+
+def extract(sdf, from_date, to_date):
+    from_t = time.mktime(datetime.strptime(from_date, "%Y/%m/%d").timetuple())
+    to_t = time.mktime(datetime.strptime(to_date, "%Y/%m/%d").timetuple())
+
+    timestamps_t = (from_t, to_t)
+    mobility_t = sdf.where(F.col('timestamp').between(*timestamps_t))
+
+    return mobility_t
\ No newline at end of file
